/* ============================================================================================================================================= /
 * LIBRARY:         RTCC PCF8563
 * FILE:            RTCC_PCF8563.h
 * LAST REV:        1.2
 * AUTHOR:          Ivo Colleoni
 * DEVICE:          PIC18F
 * CREATED:         02/12/2013
 * UPDATED:         03/12/2013
 *
 * DESCRIP:         Settaggi per RTCC_PCF8563.c
/* ============================================================================================================================================ */

/* IMPOSTAZIONI =============================================================================================================================== */
#define WRITE_ADDR                      0xA2                                            // indirizzi PCF8563

#define CONTROL_REG_ADDR                0x00
#define CONTROL_REG_2_ADDR              0x01
#define SECONDS_ADDR                    0x02
#define MINUTES_ADDR                    0x03
#define HOURS_ADDR                      0x04
#define DAY_ADDR                        0x05
#define DAY_WEEK_ADDR                   0x06
#define MONTH_ADDR                      0x07
#define YEAR_ADDR                       0x08
#define MINUTES_ALARM_ADDR              0x09
#define HOURS_ALARM_ADDR                0x0A
#define DAYS_ALARM_ADDR                 0x0B
#define DAY_WEEK_ALARM_ADDR             0x0C
#define CLOCKOUT_REG_ADR                0x0D

/* COSTANTII ================================================================================================================================== */

#define AL_ON                           0b00000000
#define AL_OFF                          0b10000000

#define CLK_OFF                         0b00000000
#define CLK_32768_Hz                    0b10000000
#define CLK_1024_Hz                     0b10000001
#define CLK_32_Hz                       0b10000010
#define CLK_1_Hz                        0b10000011


/* PROTOTIPI ================================================================================================================================== */
char RTCC_read_seconds(void);
char RTCC_read_minutes(void);
char RTCC_read_hours(void);
char RTCC_read_day(void);
char RTCC_read_month(void);
char RTCC_read_year(void);
char RTCC_read_day_w(void);
char RTCC_read_minutes_al(void);
char RTCC_read_hours_al(void);
char RTCC_read_day_al(void);
char RTCC_read_day_w_al(void);
char RTCC_write_seconds(char _seconds);
char RTCC_write_minutes(char _minutes);
char RTCC_write_hours(char _hours);
char RTCC_write_day(char _day);
char RTCC_write_month(char _month);
char RTCC_write_year(char _year);
char RTCC_write_day_w(char _day_w);
char RTCC_write_minutes_al(char _minutes_al, char _enable);
char RTCC_write_hours_al(char _hours_al, char _enable);
char RTCC_write_day_al(char _day_al, char _enable);
char RTCC_write_day_w_al(char _day_w_al, char _enable);
char RTCC_set_alarm_interrupt(char _flag);
char RTCC_clear_alarm(void);
char RTCC_clock_out(char _setting);
